@@ -6,7 +6,7 @@ use vars qw($VERSION $DEBUG);
 require Exporter;
 
 
-$VERSION = '0.05';
+$VERSION = '0.10';
 
 sub new {
     my ($pkg,@args) = @_;
@@ -533,6 +533,14 @@ Added GD as a prerequisite in Makefile.PL (version 1.16 of GD)
 
 =back
 
+=item 0.10
+
+=over 2
+
+=item *
+
+Fixed tests for Win32
+
 =back
 
 
